@@ -7,13 +7,10 @@
 // option. This file may not be copied, modified, or distributed
 // except according to those terms.
 
-/*!
-The HTML5 tokenizer from the [html5ever](https://crates.io/crates/html5ever)
-crate, repackaged with its dependencies removed.
-*/
-
+#![doc = include_str!("../README.md")]
 #![crate_type = "dylib"]
 #![cfg_attr(test, deny(warnings))]
+#![cfg_attr(docsrs, feature(doc_cfg))]
 #![allow(unused_parens)]
 
 #[macro_use]
